Package: functionals
Type: Package
Title: Functional Programming with Parallelism and Progress Tracking
Version: 0.5.0
Authors@R: 
    person("Imad", "EL BADISY", email = "elbadisyimad@gmail.com", role = c("aut", "cre"))
Maintainer: Imad EL BADISY <elbadisyimad@gmail.com>
Description: Provides functional tools such as fmap(), fwalk(), and fapply() 
    to iterate over vectors, data frames, or grouped data with optional parallelism 
    and real-time progress tracking. Designed for readable and reproducible workflows, 
    including support for Monte Carlo simulations and benchmarking.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: parallel
Suggests: testthat (>= 3.0.0), bench, rsample
Config/testthat/edition: 3
RoxygenNote: 7.3.2
BugReports: https://github.com/ielbadisy/functionals/issues
NeedsCompilation: no
Packaged: 2025-07-15 12:26:32 UTC; imad-el-badisy
Author: Imad EL BADISY [aut, cre]
Repository: CRAN
Date/Publication: 2025-07-18 15:00:08 UTC
Built: R 4.6.0; ; 2026-04-26 18:36:43 UTC; unix
