# Generated by roxygen2: do not edit by hand

export(fapply)
export(fcompose)
export(fcv)
export(floop)
export(fmap)
export(fmapc)
export(fmapg)
export(fmapn)
export(fmapr)
export(freduce)
export(frepeat)
export(fwalk)
importFrom(utils,flush.console)
